#  tests for pyaudio-0.2.11-py310hc431981_2 (this is a generated file);
print('===== testing package: pyaudio-0.2.11-py310hc431981_2 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import pyaudio
import _portaudio
#  --- run_test.py (end) ---

print('===== pyaudio-0.2.11-py310hc431981_2 OK =====');
